
clear all;
close all
clc;

%set up the model (global variables)

global  time dt x
global  line_length depth
global  sources receivers spacing
global  velocity1 velocity2 velocity3 layer1 layer2 
global  tref wref

load wavelet.mat
%load model1.mat

dt = 1;          % time sampling interval
time = 0:dt:800;  % time sampling

x = 0:10:1500;     % positions of receivers/sources

depth = 500;

line_length = x(end);                 % total length of seismic line
spacing = line_length/(length(x)-1);  % receiver spacing

% create two reflecting boundaries

xrange = [ x(1), x(end) ]';     % range of all x as a column

layer1 = [ xrange, [200, 200]' ];  % horizontal boundary (two endpoints)

layer2 = [ xrange, ((xrange-xrange(1))*tand(10)+layer1(1,2)) ];

% make velocity  columns

n1 = size(layer1,1);      % layers actually have the same range
                          % so use only n1 

v1 = ones(n1,1)*2.6;   % constant V of upper layer

v2 = ones(n1,1)*1.8;   % constant V of the wedge

v3 = ones(n1,1)*2.6;   % constant V below the wedge

rho1 = ones(n1,1)*2.0;    % densities
rho2 = ones(n1,1)*1.4;
rho3 = ones(n1,1)*2.0;

% reflectivity values

refl1 = (rho2.*v2 - rho1.*v1)./(rho2.*v2 + rho1.*v1);
refl2 = (rho3.*v3 - rho2.*v2)./(rho3.*v3 + rho2.*v2);

% determine weighted harmonic mean of velocities to the BOTTOM of the wedge

v2mean = ( (layer1(:,2)./v1 + (layer2(:,2)-layer1(:,2))./v2)./layer2(:,2) ).^(-1);

% model reflection seismograms

section = reflection_VI(x,layer1,v1,refl1) + reflection_VI(x,layer2,v2mean,refl2);

figure(1);
plot_section(x,section,'Distance(m)','b-')

title('Zero-offset section')
xlabel('x')
ylabel('Two-way travel time')

figure(2);
plot(layer1(:,1),layer1(:,2));
hold on
plot(layer2(:,1),layer2(:,2));
set(gca,'YDir','reverse')
ylim([0 600])
title('Model')
xlabel('x')
ylabel('Depth')
