clear all;
close all;
clc;

%set up the model (global variables)

global  time dt x
global  line_length depth
global  sources receivers spacing
global  velocity1 velocity2 velocity3 layer1 layer2 
global  tref wref

load wavelet.mat
%load model1.mat

depth = 200;      % selected depth of reflector

x = 0:10:1500;     % positions of receivers/sources

line_length = x(end);                 % total length of seismic line
spacing = line_length/(length(x)-1);  % receiver spacing

% mechanical properties

v1 = 2.6;
rho1 = 2.0;

v2 = 1.8;
rho2 = 1.4;

% reflection coefficient (constant for the entire profile)

R = (rho2.*v2 - rho1.*v1)./(rho2.*v2 + rho1.*v1);

% two-way reflection time to tthe level of reflectors

t0 = 2*depth/v1;

dt = 1;             % time sampling interval

time = (0.8*t0):dt:(1.5*t0);  % time sampling depending on the resulting t0
                      % for convenient viewing

% put coordinates of a horizontal reflecting boundary with three gaps
% in a common array 'xb'. The gaps are [xb(2),xb(3)], [xb(4),xb(5)], [xb(6),xb(7)]  

xb = [ x(1), 100, 150, 500, 600, 950, 1150, x(end) ]; 

  % initialize zero traces for each source/receiver and time
  
section = zeros(length(time),length(x));

% for each source/receiver at x, model reflection seismograms

    % first, find receivers located above continuous reflectors, and add to section
    % the corresponding reflections
    
ind = find( (x>=xb(1) & x<=xb(2) ) | (x>=xb(3) & x<=xb(4) ) | ...
              (x>=xb(5) & x<=xb(6) ) | (x>=xb(7) & x<=xb(8) ) );
    
for j=1:length(ind)
    k = ind(j);       % number of such receiver
    section(:,k) =  section(:,k) + wavelet(R,t0,time)';
end

    % next, for each receiver, add diffractions from all edges
    % with amplitudes decreasing as 1/distance

xedge = xb(2:(end-1));   % gap edges
    
for i=1:length(x)      
  for j=1:length(xedge)

    xdiff = xedge(j);    % location of diffractor
    
    t = 2*sqrt((xdiff-x(i))^2 + depth^2)/v1;    % time
    
    amp = R*t0/t;     % scattering amplitude, since amplitude at t0 equals R
                      % and decreases as 1/R
   
        % add this diffraction to the trace number i:
        
    section(:,i) =  section(:,i) + wavelet(amp,t,time)';
    
  end
end

  % as in other labs, scale the final section
  % so that its peak amplitude equals receiver spacing in the plot
  
section = section *(spacing/max(max(section)));
  
figure(1);
hold on
grid on

plot_section(x,section,'Distance(m)','b-')

plot(xb(1:2),[t0,t0],'r-');
plot(xb(3:4),[t0,t0],'r-');
plot(xb(5:6),[t0,t0],'r-');
plot(xb(7:8),[t0,t0],'r-');

xlim([x(1),x(end)])
title('Zero-offset section + Model (red)')
